@@ -451,6 +451,14 @@ fr_application_startup (GApplication *application)
 
 	G_APPLICATION_CLASS (fr_application_parent_class)->startup (application);
 
+	g_set_application_name (_("Archive Manager"));
+	gtk_window_set_default_icon_name ("file-roller");
+
+#ifdef ENABLE_NOTIFICATION
+	if (! notify_init (g_get_application_name ()))
+                g_warning ("Cannot initialize notification system.");
+#endif /* ENABLE_NOTIFICATION */
+
 	fr_application_register_archive_manager_service (FR_APPLICATION (application));
 	initialize_data ();
 
@@ -641,19 +649,21 @@ fr_application_local_command_line (GApplication   *application,
                                    char         ***arguments,
                                    int            *exit_status)
 {
+        char           **local_argv;
         int              local_argc;
         GOptionContext  *context;
         GError          *error = NULL;
         gboolean         handled_locally = FALSE;
 
-        local_argc = g_strv_length (*arguments);
+        local_argv = g_strdupv (*arguments);
+        local_argc = g_strv_length (local_argv);
 
-        program_argv0 = *arguments[0];
+        program_argv0 = local_argv[0];
         *exit_status = 0;
 
         context = fr_application_create_option_context ();
         g_option_context_set_ignore_unknown_options (context, TRUE);
-	if (! g_option_context_parse (context, &local_argc, arguments, &error)) {
+	if (! g_option_context_parse (context, &local_argc, &local_argv, &error)) {
 		*exit_status = EXIT_FAILURE;
 		g_critical ("Failed to parse arguments: %s", error->message);
                 g_clear_error (&error);
@@ -666,6 +676,7 @@ fr_application_local_command_line (GApplication   *application,
 	}
 
 	g_option_context_free (context);
+        g_strfreev (local_argv);
 
         return handled_locally;
 }
@@ -710,16 +721,6 @@ fr_application_class_init (FrApplicationClass *klass)
 static void
 fr_application_init (FrApplication *self)
 {
-	/* set the name and icon */
-
-	g_set_application_name (_("Archive Manager"));
-	gtk_window_set_default_icon_name ("file-roller");
-
-#ifdef ENABLE_NOTIFICATION
-	if (! notify_init (g_get_application_name ()))
-                g_warning ("Cannot initialize notification system.");
-#endif /* ENABLE_NOTIFICATION */
-
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, FR_TYPE_APPLICATION, FrApplicationPrivate);
 	self->priv->owner_id = 0;
 	self->priv->introspection_data = NULL;
